summaryrefslogtreecommitdiffstats
path: root/src/import/generic/memory/lib/spd/spd_fields_ddr4.H
diff options
context:
space:
mode:
authorMark Pizzutillo <Mark.Pizzutillo@ibm.com>2020-01-27 19:13:30 -0500
committerChristian R Geddes <crgeddes@us.ibm.com>2020-02-12 12:41:59 -0600
commit798af67f241d6a8479c952485099e7b60d4aa823 (patch)
tree00e462b989ecc1fd2995fa203f24e7c31856b5a1 /src/import/generic/memory/lib/spd/spd_fields_ddr4.H
parent3dbe6a1963d4561ff5bca378caf9e107e7807bfc (diff)
downloadtalos-hostboot-798af67f241d6a8479c952485099e7b60d4aa823.tar.gz
talos-hostboot-798af67f241d6a8479c952485099e7b60d4aa823.zip
Add attribute for SPD_REVISION (byte 1)
Rename previous uses of Byte 192, the ddimm module spd section to avoid ambiguity. Renamed from spd_revision --> ddimm_module_spd_revision git-coreq:hostboot:I039173097619111ae5847660472e75ed9f2d5f1d git-coreq:sbe:I039173097619111ae5847660472e75ed9f2d5f1d git-coreq:hwsv:I039173097619111ae5847660472e75ed9f2d5f1d Change-Id: I039173097619111ae5847660472e75ed9f2d5f1d Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/90410 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Tested-by: PPE CI <ppe-ci+hostboot@us.ibm.com> Reviewed-by: STEPHEN GLANCY <sglancy@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Reviewed-by: Louis Stermole <stermole@us.ibm.com> Reviewed-by: Jennifer A Stofer <stofer@us.ibm.com> Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/90508 Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Christian R Geddes <crgeddes@us.ibm.com>
Diffstat (limited to 'src/import/generic/memory/lib/spd/spd_fields_ddr4.H')
-rw-r--r--src/import/generic/memory/lib/spd/spd_fields_ddr4.H14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/import/generic/memory/lib/spd/spd_fields_ddr4.H b/src/import/generic/memory/lib/spd/spd_fields_ddr4.H
index b60e69222..c05527045 100644
--- a/src/import/generic/memory/lib/spd/spd_fields_ddr4.H
+++ b/src/import/generic/memory/lib/spd/spd_fields_ddr4.H
@@ -5,7 +5,7 @@
/* */
/* OpenPOWER HostBoot Project */
/* */
-/* Contributors Listed Below - COPYRIGHT 2018,2019 */
+/* Contributors Listed Below - COPYRIGHT 2018,2020 */
/* [+] International Business Machines Corp. */
/* */
/* */
@@ -795,10 +795,10 @@ class fields<DDR4, DDIMM_MODULE>
enum
{
- // Byte 192: SPD Revision for bytes 192->447
- SPD_REV_BYTE = 192,
- SPD_REVISION_START = 0,
- SPD_REVISION_LEN = 8,
+ // Byte 192: SPD Revision DDIMM Module Type (bytes 192->447)
+ SPD_REV_DDIMM_MODULE_BYTE = 192,
+ SPD_REV_DDIMM_MODULE_START = 0,
+ SPD_REV_DDIMM_MODULE_LEN = 8,
// Byte 193: Module Height
MODULE_HEIGHT_BYTE = 193,
@@ -1192,8 +1192,8 @@ class fields<DDR4, DDIMM_MODULE>
// Second field - start bit
// Third field - bit length
- // Byte 192: SPD Revision for bytes 192->447
- static constexpr field_t SPD_REVISION{SPD_REV_BYTE, SPD_REVISION_START, SPD_REVISION_LEN};
+ // Byte 192: SPD Revision DDIMM Module Bytes (192->447)
+ static constexpr field_t SPD_REV_DDIMM_MODULE{SPD_REV_DDIMM_MODULE_BYTE, SPD_REV_DDIMM_MODULE_START, SPD_REV_DDIMM_MODULE_LEN};
// Byte 193: Module Height
static constexpr field_t MODULE_BASE_HEIGHT{MODULE_HEIGHT_BYTE, MODULE_BASE_HEIGHT_START, MODULE_BASE_HEIGHT_LEN};
OpenPOWER on IntegriCloud